# imr (Intelligent Model Registry)

This is a command-line interface and library for managing inteligent models.

You can install the [imr](https://github.com/eccenca/imr) command-line and library
with pip as following:

```
pip install imr
```

